@@ -46,6 +46,7 @@
 #define DEFAULT_ENABLE_KEYBOARD_SHORTCUTS         TRUE
 #define DEFAULT_SHOW_NOTIFICATIONS                1
 #define DEFAULT_PLAY_SOUND                        FALSE
+#define DEFAULT_REC_INDICATOR_PERSISTENT          FALSE
 #define DEFAULT_VOLUME_STEP                       5
 #define DEFAULT_VOLUME_MAX                        150
 
@@ -56,6 +57,7 @@
 #define DEFAULT_ENABLE_MPRIS                      FALSE
 #define DEFAULT_ENABLE_MULTIMEDIA_KEYS            FALSE
 #endif
+#define DEFAULT_MULTIMEDIA_KEYS_TO_ALL            FALSE
 #define DEFAULT_IGNORED_PLAYERS                   ""
 #define DEFAULT_PERSISTENT_PLAYERS                ""
 
@@ -90,10 +92,12 @@ struct _PulseaudioConfig
 
   gboolean         enable_keyboard_shortcuts;
   gboolean         enable_multimedia_keys;
+  gboolean         multimedia_keys_to_all;
   guint            show_notifications;
 #ifdef HAVE_LIBCANBERRA
   gboolean         play_sound;
 #endif
+  gboolean         rec_indicator_persistent;
   guint            volume_step;
   guint            volume_max;
   gchar           *mixer_command;
@@ -111,10 +115,12 @@ enum
     PROP_0,
     PROP_ENABLE_KEYBOARD_SHORTCUTS,
     PROP_ENABLE_MULTIMEDIA_KEYS,
+    PROP_MULTIMEDIA_KEYS_TO_ALL,
     PROP_SHOW_NOTIFICATIONS,
 #ifdef HAVE_LIBCANBERRA
     PROP_PLAY_SOUND,
 #endif
+    PROP_REC_INDICATOR_PERSISTENT,
     PROP_VOLUME_STEP,
     PROP_VOLUME_MAX,
     PROP_MIXER_COMMAND,
@@ -168,6 +174,15 @@ pulseaudio_config_class_init (PulseaudioConfigClass *klass)
 
 
 
+  g_object_class_install_property (gobject_class,
+                                   PROP_MULTIMEDIA_KEYS_TO_ALL,
+                                   g_param_spec_boolean ("multimedia-keys-to-all", NULL, NULL,
+                                                         DEFAULT_MULTIMEDIA_KEYS_TO_ALL,
+                                                         G_PARAM_READWRITE |
+                                                         G_PARAM_STATIC_STRINGS));
+
+
+
   g_object_class_install_property (gobject_class,
                                    PROP_SHOW_NOTIFICATIONS,
                                    g_param_spec_uint ("show-notifications", NULL, NULL,
@@ -188,6 +203,14 @@ pulseaudio_config_class_init (PulseaudioConfigClass *klass)
 #endif
 
 
+  g_object_class_install_property (gobject_class,
+                                   PROP_REC_INDICATOR_PERSISTENT,
+                                   g_param_spec_boolean ("rec-indicator-persistent", NULL, NULL,
+                                                         DEFAULT_REC_INDICATOR_PERSISTENT,
+                                                         G_PARAM_READWRITE |
+                                                         G_PARAM_STATIC_STRINGS));
+
+
   g_object_class_install_property (gobject_class,
                                    PROP_VOLUME_STEP,
                                    g_param_spec_uint ("volume-step", NULL, NULL,
@@ -279,10 +302,12 @@ pulseaudio_config_init (PulseaudioConfig *config)
 {
   config->enable_keyboard_shortcuts = DEFAULT_ENABLE_KEYBOARD_SHORTCUTS;
   config->enable_multimedia_keys    = DEFAULT_ENABLE_MULTIMEDIA_KEYS;
+  config->multimedia_keys_to_all    = DEFAULT_MULTIMEDIA_KEYS_TO_ALL;
   config->show_notifications        = DEFAULT_SHOW_NOTIFICATIONS;
 #ifdef HAVE_LIBCANBERRA
   config->play_sound                = DEFAULT_PLAY_SOUND;
 #endif
+  config->rec_indicator_persistent  = DEFAULT_REC_INDICATOR_PERSISTENT;
   config->volume_step               = DEFAULT_VOLUME_STEP;
   config->volume_max                = DEFAULT_VOLUME_MAX;
   config->mixer_command             = g_strdup (DEFAULT_MIXER_COMMAND);
@@ -326,6 +351,10 @@ pulseaudio_config_get_property (GObject    *object,
       g_value_set_boolean (value, config->enable_multimedia_keys);
       break;
 
+    case PROP_MULTIMEDIA_KEYS_TO_ALL:
+      g_value_set_boolean (value, config->multimedia_keys_to_all);
+      break;
+
     case PROP_SHOW_NOTIFICATIONS:
       g_value_set_uint (value, config->show_notifications);
       break;
@@ -336,6 +365,10 @@ pulseaudio_config_get_property (GObject    *object,
       break;
 #endif
 
+    case PROP_REC_INDICATOR_PERSISTENT:
+      g_value_set_boolean (value, config->rec_indicator_persistent);
+      break;
+
     case PROP_VOLUME_STEP:
       g_value_set_uint (value, config->volume_step);
       break;
@@ -408,6 +441,16 @@ pulseaudio_config_set_property (GObject      *object,
         }
       break;
 
+    case PROP_MULTIMEDIA_KEYS_TO_ALL:
+      val_bool = g_value_get_boolean (value);
+      if (config->multimedia_keys_to_all != val_bool)
+        {
+          config->multimedia_keys_to_all = val_bool;
+          g_object_notify (G_OBJECT (config), "multimedia-keys-to-all");
+          g_signal_emit (G_OBJECT (config), pulseaudio_config_signals [CONFIGURATION_CHANGED], 0);
+        }
+      break;
+
     case PROP_SHOW_NOTIFICATIONS:
       val_uint = g_value_get_uint (value);
       if (config->show_notifications != val_uint)
@@ -430,6 +473,16 @@ pulseaudio_config_set_property (GObject      *object,
       break;
 #endif
 
+    case PROP_REC_INDICATOR_PERSISTENT:
+      val_bool = g_value_get_boolean (value);
+      if (config->rec_indicator_persistent != val_bool)
+        {
+          config->rec_indicator_persistent = val_bool;
+          g_object_notify (G_OBJECT (config), "rec-indicator-persistent");
+          g_signal_emit (G_OBJECT (config), pulseaudio_config_signals [CONFIGURATION_CHANGED], 0);
+        }
+      break;
+
     case PROP_VOLUME_STEP:
       val_uint = g_value_get_uint (value);
       if (config->volume_step != val_uint)
@@ -534,6 +587,16 @@ pulseaudio_config_get_enable_multimedia_keys (PulseaudioConfig *config)
 
 
 
+gboolean
+pulseaudio_config_get_multimedia_keys_to_all (PulseaudioConfig *config)
+{
+  g_return_val_if_fail (IS_PULSEAUDIO_CONFIG (config), DEFAULT_MULTIMEDIA_KEYS_TO_ALL);
+
+  return config->multimedia_keys_to_all;
+}
+
+
+
 guint
 pulseaudio_config_get_show_notifications (PulseaudioConfig *config)
 {
@@ -556,6 +619,16 @@ pulseaudio_config_get_play_sound (PulseaudioConfig *config)
 
 
 
+gboolean
+pulseaudio_config_get_rec_indicator_persistent (PulseaudioConfig *config)
+{
+  g_return_val_if_fail (IS_PULSEAUDIO_CONFIG (config), DEFAULT_REC_INDICATOR_PERSISTENT);
+
+  return config->rec_indicator_persistent;
+}
+
+
+
 guint
 pulseaudio_config_get_volume_step (PulseaudioConfig *config)
 {
@@ -994,6 +1067,10 @@ pulseaudio_config_new (const gchar     *property_base)
       xfconf_g_property_bind (channel, property, G_TYPE_BOOLEAN, config, "enable-multimedia-keys");
       g_free (property);
 
+      property = g_strconcat (property_base, "/multimedia-keys-to-all", NULL);
+      xfconf_g_property_bind (channel, property, G_TYPE_BOOLEAN, config, "multimedia-keys-to-all");
+      g_free (property);
+
       property = g_strconcat (property_base, "/show-notifications", NULL);
       xfconf_g_property_bind (channel, property, G_TYPE_UINT, config, "show-notifications");
       g_free (property);
@@ -1004,6 +1081,10 @@ pulseaudio_config_new (const gchar     *property_base)
       g_free (property);
 #endif
 
+      property = g_strconcat (property_base, "/rec-indicator-persistent", NULL);
+      xfconf_g_property_bind (channel, property, G_TYPE_BOOLEAN, config, "rec-indicator-persistent");
+      g_free (property);
+
       property = g_strconcat (property_base, "/volume-step", NULL);
       xfconf_g_property_bind (channel, property, G_TYPE_UINT, config, "volume-step");
       g_free (property);
