@@ -46,14 +46,6 @@
 
 #include <exo/exo.h>
 
-#define PLUGIN_WEBSITE  "https://docs.xfce.org/apps/pulseaudio-plugin/start"
-
-#ifdef LIBXFCE4UI_CHECK_VERSION
-#if LIBXFCE4UI_CHECK_VERSION (4, 9, 0)
-#define HAS_ONLINE_HELP
-#endif
-#endif
-
 
 
 static void              pulseaudio_dialog_build                  (PulseaudioDialog          *dialog);
@@ -174,7 +166,7 @@ pulseaudio_dialog_persistent_toggled_cb (GtkCellRendererToggle *toggle, gchar *p
   treepath = gtk_tree_path_new_from_string (path);
   gtk_tree_model_get_iter (model, &iter, treepath);
 
-  gtk_tree_model_get_value (model, &iter, 1, &player_val);
+  gtk_tree_model_get_value (model, &iter, 4, &player_val);
   gtk_tree_model_get_value (model, &iter, 2, &persistent_val);
   persistent = !g_value_get_boolean(&persistent_val);
   player = g_value_get_string(&player_val);
@@ -204,7 +196,7 @@ pulseaudio_dialog_ignored_toggled_cb (GtkCellRendererToggle *toggle, gchar *path
   treepath = gtk_tree_path_new_from_string (path);
   gtk_tree_model_get_iter (model, &iter, treepath);
 
-  gtk_tree_model_get_value (model, &iter, 1, &player_val);
+  gtk_tree_model_get_value (model, &iter, 4, &player_val);
   gtk_tree_model_get_value (model, &iter, 3, &ignored_val);
   ignored = !g_value_get_boolean(&ignored_val);
   player = g_value_get_string(&player_val);
@@ -295,6 +287,11 @@ pulseaudio_dialog_build (PulseaudioDialog *dialog)
       gtk_widget_set_visible (GTK_WIDGET (object), FALSE);
 #endif
 
+      object = gtk_builder_get_object (builder, "checkbutton-rec-indicator-persistent");
+      g_object_bind_property (G_OBJECT (dialog->config), "rec-indicator-persistent",
+                              G_OBJECT (object), "active",
+                              G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
+
       object = gtk_builder_get_object (builder, "spinbutton-volume-step");
       g_return_if_fail (GTK_IS_ENTRY (object));
       g_object_bind_property (G_OBJECT (dialog->config), "volume-step",
@@ -335,7 +332,13 @@ pulseaudio_dialog_build (PulseaudioDialog *dialog)
                              G_OBJECT(object), "active",
                              G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
 
-      g_object_bind_property(G_OBJECT(dialog->config), "enable-mpris",
+      object = gtk_builder_get_object(builder, "checkbutton-multimedia-keys-to-all");
+      g_return_if_fail(GTK_IS_CHECK_BUTTON(object));
+      g_object_bind_property(G_OBJECT(dialog->config), "multimedia-keys-to-all",
+                             G_OBJECT(object), "active",
+                             G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
+
+      g_object_bind_property(G_OBJECT(dialog->config), "enable-multimedia-keys",
                              G_OBJECT(object), "sensitive",
                              G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
 
@@ -358,10 +361,11 @@ pulseaudio_dialog_build (PulseaudioDialog *dialog)
           const guint num_players = g_strv_length (players);
           for (i = 0; i < num_players; i++)
             {
+              gchar *player_label = NULL;
               gchar *icon_name = NULL;
               GIcon *icon = NULL;
 
-              if (pulseaudio_mpris_get_player_summary (players[i], &icon_name, NULL))
+              if (pulseaudio_mpris_get_player_summary (players[i], &player_label, &icon_name, NULL))
                 {
                   if (g_file_test (icon_name, G_FILE_TEST_EXISTS) && !g_file_test (icon_name, G_FILE_TEST_IS_DIR))
                     {
@@ -381,11 +385,13 @@ pulseaudio_dialog_build (PulseaudioDialog *dialog)
                   gtk_list_store_append (liststore, &iter);
                   gtk_list_store_set (liststore, &iter,
                                       0, icon,
-                                      1, players[i],
+                                      1, player_label,
                                       2, pulseaudio_config_player_persistent_lookup (dialog->config, players[i]),
                                       3, pulseaudio_config_player_ignored_lookup (dialog->config, players[i]),
+                                      4, players[i],
                                       -1);
 
+                  g_free (player_label);
                   g_free (icon_name);
                   if (icon != NULL)
                     g_object_unref (icon);
@@ -435,24 +441,11 @@ static void
 pulseaudio_dialog_help_button_clicked (PulseaudioDialog *dialog,
                                        GtkWidget        *button)
 {
-  #ifndef HAS_ONLINE_HELP
-  gboolean result;
-  #endif
-
   g_return_if_fail (IS_PULSEAUDIO_DIALOG (dialog));
   g_return_if_fail (GTK_IS_BUTTON (button));
   g_return_if_fail (GTK_IS_WINDOW (dialog->dialog));
 
-  #ifdef HAS_ONLINE_HELP
   xfce_dialog_show_help (GTK_WINDOW (dialog->dialog), "pulseaudio-plugin", "start", NULL);
-  #else
-
-  result = g_spawn_command_line_async ("exo-open --launch WebBrowser " PLUGIN_WEBSITE, NULL);
-
-  if (G_UNLIKELY (result == FALSE))
-    g_warning ("Unable to open the following url: %s", PLUGIN_WEBSITE);
-
-  #endif
 }
 
 
